import dislib as ds
from dislib.classification import KNeighborsClassifier
from dislib.model_selection import GridSearchCV
from dislib.data import load_txt_file
import pandas as pd
from pycompss.api.parameter import *
from pycompss.api.task import task
from pycompss.api.api import compss_wait_on_file
from sklearn.preprocessing import LabelEncoder
import numpy as np
import json


@task(filename_save=FILE_OUT)
def save_data(filename_save, data):
    for key in data:
        if not isinstance(data[key], list):
            data[key] = data[key].tolist()
    with open(filename_save, "w") as f:
        json.dump(data, f)
    f.close()

def main():
    iris_dataset = sys.argv[1]
    iris_pd = pd.read_csv(iris_dataset)
    encoded_data = LabelEncoder().fit_transform(np.array(iris_pd.variety))
    encoded_data = encoded_data + 1
    iris_pd = iris_pd.drop(columns=["variety"])
    full_data = pd.concat([iris_pd, pd.DataFrame({'variety': encoded_data})], axis=1)
    iris_np = full_data.to_numpy()

    x = ds.array(iris_np[:, :4], (150, 4))
    y = ds.array(iris_np[:, -1], (150, 1))
    param_grid = {'n_neighbors': [3, 5, 7], 'weights': ['uniform', 'distance']}
    knn = KNeighborsClassifier()
    searcher = GridSearchCV(knn, param_grid, cv=3, refit=False)
    searcher.fit(x, y)
    save_data("gridsearch_results.json", searcher.cv_results_)




if __name__ == '__main__':
    main()

